@@ -387,20 +387,22 @@ static int y_write_double(
 	yaml_event_t event;
 	int omit_tag = 0;
 	int status;
-	char res[PHP_DOUBLE_MAX_LENGTH];
+	char *res = { 0 };
+	size_t res_size;
 
 	if (NULL == tag) {
 		tag = (yaml_char_t *) YAML_FLOAT_TAG;
 		omit_tag = 1;
 	}
 
-	// Bug 79866: let PHP determine output precision
-	php_gcvt(Z_DVAL_P(data), (int)PG(serialize_precision), '.', 'E', res);
+	res_size = snprintf(res, 0, "%f", Z_DVAL_P(data));
+	res = (char*) emalloc(res_size + 1);
+	snprintf(res, res_size + 1, "%f", Z_DVAL_P(data));
 
 	status = yaml_scalar_event_initialize(&event, NULL, tag,
 			(yaml_char_t *) res, strlen(res),
 			omit_tag, omit_tag, YAML_PLAIN_SCALAR_STYLE);
-
+	efree(res);
 	if (!status) {
 		y_event_init_failed(&event);
 		return FAILURE;
@@ -504,9 +506,9 @@ static int y_write_array(
 	recursive_idx = y_search_recursive(state, (zend_ulong) ht);
 	if (-1 != recursive_idx) {
 		/* create anchor to refer to this structure */
-		anchor_size = snprintf(anchor, 0, "refid" ZEND_LONG_FMT, recursive_idx + 1);
+		anchor_size = snprintf(anchor, 0, "refid%ld", recursive_idx + 1);
 		anchor = (char*) emalloc(anchor_size + 1);
-		snprintf(anchor, anchor_size + 1, "refid" ZEND_LONG_FMT, recursive_idx + 1);
+		snprintf(anchor, anchor_size + 1, "refid%ld", recursive_idx + 1);
 
 #if PHP_VERSION_ID >= 70300
 		if (!(GC_FLAGS(ht) & GC_IMMUTABLE) && GC_IS_RECURSIVE(ht)) {
@@ -718,11 +720,10 @@ y_write_object_callback (
 	zval *ztag;
 	zval *zdata;
 	zend_string *str_key;
-	int result;
 
 	/* call the user function */
-	if (FAILURE == call_user_function(EG(function_table), NULL,
-			callback, &zret, 1, argv) ||
+	if (FAILURE == call_user_function_ex(EG(function_table), NULL,
+			callback, &zret, 1, argv, 0, NULL) ||
 			Z_TYPE_P(&zret) == IS_UNDEF) {
 		php_error_docref(NULL, E_WARNING,
 				"Failed to apply callback for class '%s'"
@@ -735,7 +736,6 @@ y_write_object_callback (
 		php_error_docref(NULL, E_WARNING,
 				"Expected callback for class '%s'"
 				" to return an array", clazz_name);
-		zval_ptr_dtor(&zret);
 		return FAILURE;
 	}
 
@@ -762,12 +762,10 @@ y_write_object_callback (
 	}
 	zend_string_release(str_key);
 
-	/* emit surrogate object and tag */
-	result = y_write_zval(
-			state, zdata, (yaml_char_t *) Z_STRVAL_P(ztag));
 
-	zval_ptr_dtor(&zret);
-	return result;
+	/* emit surrogate object and tag */
+	return y_write_zval(
+			state, zdata, (yaml_char_t *) Z_STRVAL_P(ztag));
 }
 /* }}} */
 
